::  UZ Creation Organizer v1.03 (2019) by GreenTea
::  12/30/2019
::  Contact: devilangelox@gmail.com
::	==============================================
::	This is a simple batch script tool to make handling multiple files or unstructured directories easier if you want to make server-side files (UZ).
::	
::	The tool was made for 2 things:
::	1. Sort the needed files for server-side usage from messy directory structures (usually by extracting multiple .zip files with mutators/maps at once).
::	2. To make .UZ files from them all at once.
::	
::	In both cases, after the process, the files will be organized into two seperate folders; 'Filtered_results' and 'UZ'.
::	
::	How to use:
::	Extract the zip in the root of your UT folder. 
::	For example: D:\UT99\UZ Creation Organizer
::	
::	Place extracted map packs/mods/mutators in the /- CONTAINER UT FILES [DO_NOT_DELETE]/ folder.
::	and execute 'UZ batchscript.bat'
::	
::	The script will take care of the most important files (.U, .UNR, .UMX, .UTX, etc.) inside '- CONTAINER UT FILES [DO_NOT_DELETE]', regardless of directory structure.
::  This means that even if you put loose files in maps other than Maps/Music/Sounds/System/Textures, or even the root, the output will sort those in their respective folders.
::  Just put your files/folders in the CONTAINER folder and run the script to save yourself the time of sorting.
::
::
::  Final notes:
::  I made this for personal use, but if you're like me, it gets annoying after a while to have to perform multiple search queries to take out the right files.
::  Originally it consisted of two separate scripts but decided to merge them together for ease of use. I had fun making this since batch script tools can be super handy.
::	
::	- GreenTea (devilangelox@gmail.com)
::	
:: 
::  Changelog:
::
:: v1.03
:: =====
:: - Fixed a typo in standard files list.
:: - Improved and tidied up some scripting.
:: - Removed redundant checkup scripts.
:: - Added extra notifications to highlight current process.
:: - Filtered_results will always have structured directory, and will always be processed even if CONTAINER is empty.
:: - Added extra prompts.
:: - Added more error checking.
:: - Edited the description.
::
::
:: v1.02
:: =====
:: - Option to skip default files added.
::
:: - Filtered_results (.u,.umx,.uax,.utx,.unr) now gets organized first before proceeding with UZ compression.
::   If you only want to organize, you may close the window after you see the "Unreal files copied to Filtered_results." message.
::
:: - When a filetype is not present, its respective folder will not be created.
::
:: - Cleaned a bit of scripting.
::
::
:: v1.01
:: =====
:: - Tool now tells you when a file type is not present and will attempt to continue.
::
:: - Collected files in the 'Filtered_results' folder are placed in their respective folders (Maps,Music,Sounds,System,Textures)
::
::
:: v1.00
:: =====
:: - Initial release
::  

@ECHO off
ECHO.
ECHO.  ::::::::::::::::::::::::::::::::::::::::::::::::::::::
ECHO.  ::: UZ Creation Organizer v1.03 (2019) by GreenTea :::
ECHO.  ::: Contact: devilangelox@gmail.com                :::
ECHO.  ::::::::::::::::::::::::::::::::::::::::::::::::::::::

ECHO.
ECHO   Beginning filtered search for UT files...
PUSHD "%~dp0"
IF NOT EXIST Filtered_results md Filtered_results >nul
for /r "./- CONTAINER UT FILES [DO_NOT_DELETE]" %%x in (*.u *.umx *.uax *.utx *.unr) do copy "%%x" "Filtered_results" >nul

ECHO.

:checkcontainer
set _TMP=
for /f "delims=" %%a in ('dir /b "./- CONTAINER UT FILES [DO_NOT_DELETE]/"') do set _TMP="%%a"
IF {%_TMP%}=={} (
	ECHO   No files present in CONTAINER. Add files/folders to CONTAINER to make structured directory or .UZ files.
	ECHO.   
	GOTO :checkexist
) ELSE (
   	GOTO choice
)
:checkexist
set _TMP=
for /f "delims=" %%a in ('dir /b "./Filtered_results"') do set _TMP="%%a"
IF {%_TMP%}=={} (
	ECHO   
	ECHO.   
	GOTO :exit
) ELSE (
   	GOTO :choicefilteredfilespresent
)


:exit
ECHO   Press any key to exit
pause >nul
exit
:abort
ECHO.
ECHO.
ECHO   Aborted.
ECHO.
ECHO.
ECHO   Press any key to exit
pause >nul
exit


:choice
CHOICE /C:YN /M "> Skip default files? Y=Yes N=No"%1
IF ERRORLEVEL ==2 GOTO include
IF ERRORLEVEL ==1 GOTO skip
:choicefilteredfilespresent
ECHO.  But files in Filtered_results were found, proceeding...
ECHO.  
CHOICE /C:YNC /M "> Skip default files? Y=Yes N=No C=Abort"%1
IF ERRORLEVEL ==3 GOTO abort
IF ERRORLEVEL ==2 GOTO include
IF ERRORLEVEL ==1 GOTO skip
:include
ECHO   -- Including default files
GOTO ucheck
:skip
ECHO   -- Skipping default files
GOTO standardfiles


:standardfiles
IF EXIST Filtered_results\Activates.uax del Filtered_results\Activates.uax
IF EXIST Filtered_results\Addon1.uax del Filtered_results\Addon1.uax
IF EXIST Filtered_results\AlfaFX.utx del Filtered_results\AlfaFX.utx
IF EXIST Filtered_results\AmbAncient.uax del Filtered_results\AmbAncient.uax
IF EXIST Filtered_results\AmbCity.uax del Filtered_results\AmbCity.uax
IF EXIST Filtered_results\AmbModern.uax del Filtered_results\AmbModern.uax
IF EXIST Filtered_results\AmbOutside.uax del Filtered_results\AmbOutside.uax
IF EXIST Filtered_results\Ancient.utx del Filtered_results\Ancient.utx
IF EXIST Filtered_results\Announcer.uax del Filtered_results\Announcer.uax
IF EXIST Filtered_results\ArenaTex.utx del Filtered_results\ArenaTex.utx
IF EXIST Filtered_results\AS-Frigate.unr del Filtered_results\AS-Frigate.unr
IF EXIST Filtered_results\AS-Guardia.unr del Filtered_results\AS-Guardia.unr
IF EXIST Filtered_results\AS-HiSpeed.unr del Filtered_results\AS-HiSpeed.unr
IF EXIST Filtered_results\AS-Mazon.unr del Filtered_results\AS-Mazon.unr
IF EXIST Filtered_results\AS-OceanFloor.unr del Filtered_results\AS-OceanFloor.unr
IF EXIST Filtered_results\AS-Overlord.unr del Filtered_results\AS-Overlord.unr
IF EXIST Filtered_results\AS-Rook.unr del Filtered_results\AS-Rook.unr
IF EXIST Filtered_results\AS-Tutorial.unr del Filtered_results\AS-Tutorial.unr
IF EXIST Filtered_results\Belt_fx.utx del Filtered_results\Belt_fx.utx
IF EXIST Filtered_results\BluffFX.utx del Filtered_results\BluffFX.utx
IF EXIST Filtered_results\BossSkins.utx del Filtered_results\BossSkins.utx
IF EXIST Filtered_results\BossVoice.uax del Filtered_results\BossVoice.uax
IF EXIST Filtered_results\Botmca9.umx del Filtered_results\Botmca9.umx
IF EXIST Filtered_results\BotPack.u del Filtered_results\BotPack.u
IF EXIST Filtered_results\Botpck10.umx del Filtered_results\Botpck10.umx
IF EXIST Filtered_results\Cannon.umx del Filtered_results\Cannon.umx
IF EXIST Filtered_results\castle1.utx del Filtered_results\castle1.utx
IF EXIST Filtered_results\ChizraEFX.utx del Filtered_results\ChizraEFX.utx
IF EXIST Filtered_results\city.utx del Filtered_results\city.utx
IF EXIST Filtered_results\CityIntro.unr del Filtered_results\CityIntro.unr
IF EXIST Filtered_results\Colossus.umx del Filtered_results\Colossus.umx
IF EXIST Filtered_results\commandoskins.utx del Filtered_results\commandoskins.utx
IF EXIST Filtered_results\core.u del Filtered_results\core.u
IF EXIST Filtered_results\Coret_FX.utx del Filtered_results\Coret_FX.utx
IF EXIST Filtered_results\Course.umx del Filtered_results\Course.umx
IF EXIST Filtered_results\Creative.utx del Filtered_results\Creative.utx
IF EXIST Filtered_results\Credits.umx del Filtered_results\Credits.umx
IF EXIST Filtered_results\credits.utx del Filtered_results\credits.utx
IF EXIST Filtered_results\Crypt.utx del Filtered_results\Crypt.utx
IF EXIST Filtered_results\Crypt_FX.utx del Filtered_results\Crypt_FX.utx
IF EXIST Filtered_results\Crypt2.utx del Filtered_results\Crypt2.utx
IF EXIST Filtered_results\CTF.utx del Filtered_results\CTF.utx
IF EXIST Filtered_results\CTF-Command.unr del Filtered_results\CTF-Command.unr
IF EXIST Filtered_results\CTF-Coret.unr del Filtered_results\CTF-Coret.unr
IF EXIST Filtered_results\CTF-Dreary.unr del Filtered_results\CTF-Dreary.unr
IF EXIST Filtered_results\CTF-EternalCave.unr del Filtered_results\CTF-EternalCave.unr
IF EXIST Filtered_results\CTF-Face.unr del Filtered_results\CTF-Face.unr
IF EXIST Filtered_results\CTF-Gauntlet.unr del Filtered_results\CTF-Gauntlet.unr
IF EXIST Filtered_results\CTF-LavaGiant.unr del Filtered_results\CTF-LavaGiant.unr
IF EXIST Filtered_results\CTF-Niven.unr del Filtered_results\CTF-Niven.unr
IF EXIST Filtered_results\CTF-November.unr del Filtered_results\CTF-November.unr
IF EXIST Filtered_results\CTF-Tutorial.unr del Filtered_results\CTF-Tutorial.unr
IF EXIST Filtered_results\DacomaFem.utx del Filtered_results\DacomaFem.utx
IF EXIST Filtered_results\DacomaSkins.utx del Filtered_results\DacomaSkins.utx
IF EXIST Filtered_results\DDay.uax del Filtered_results\DDay.uax
IF EXIST Filtered_results\DDayFX.utx del Filtered_results\DDayFX.utx
IF EXIST Filtered_results\DecayedS.utx del Filtered_results\DecayedS.utx
IF EXIST Filtered_results\Detail.utx del Filtered_results\Detail.utx
IF EXIST Filtered_results\DMatch.uax del Filtered_results\DMatch.uax
IF EXIST Filtered_results\DM-Barricade.unr del Filtered_results\DM-Barricade.unr
IF EXIST Filtered_results\DM-Codex.unr del Filtered_results\DM-Codex.unr
IF EXIST Filtered_results\DM-Conveyor.unr del Filtered_results\DM-Conveyor.unr
IF EXIST Filtered_results\DM-Curse][.unr del Filtered_results\DM-Curse][.unr
IF EXIST Filtered_results\DM-Deck16][.unr del Filtered_results\DM-Deck16][.unr
IF EXIST Filtered_results\DMeffects.utx del Filtered_results\DMeffects.utx
IF EXIST Filtered_results\DM-Fetid.unr del Filtered_results\DM-Fetid.unr
IF EXIST Filtered_results\DM-Fractal.unr del Filtered_results\DM-Fractal.unr
IF EXIST Filtered_results\DM-Gothic.unr del Filtered_results\DM-Gothic.unr
IF EXIST Filtered_results\DM-Grinder.unr del Filtered_results\DM-Grinder.unr
IF EXIST Filtered_results\DM-HyperBlast.unr del Filtered_results\DM-HyperBlast.unr
IF EXIST Filtered_results\DM-KGalleon.unr del Filtered_results\DM-KGalleon.unr
IF EXIST Filtered_results\DM-Liandri.unr del Filtered_results\DM-Liandri.unr
IF EXIST Filtered_results\DM-Morbias][.unr del Filtered_results\DM-Morbias][.unr
IF EXIST Filtered_results\DM-Morpheus.unr del Filtered_results\DM-Morpheus.unr
IF EXIST Filtered_results\DM-Oblivion.unr del Filtered_results\DM-Oblivion.unr
IF EXIST Filtered_results\DM-Peak.unr del Filtered_results\DM-Peak.unr
IF EXIST Filtered_results\DM-Phobos.unr del Filtered_results\DM-Phobos.unr
IF EXIST Filtered_results\DM-Pressure.unr del Filtered_results\DM-Pressure.unr
IF EXIST Filtered_results\DM-Pyramid.unr del Filtered_results\DM-Pyramid.unr
IF EXIST Filtered_results\DM-Stalwart.unr del Filtered_results\DM-Stalwart.unr
IF EXIST Filtered_results\DM-StalwartXL.unr del Filtered_results\DM-StalwartXL.unr
IF EXIST Filtered_results\DM-Tempest.unr del Filtered_results\DM-Tempest.unr
IF EXIST Filtered_results\DM-Turbine.unr del Filtered_results\DM-Turbine.unr
IF EXIST Filtered_results\DM-Tutorial.unr del Filtered_results\DM-Tutorial.unr
IF EXIST Filtered_results\DM-Zeto.unr del Filtered_results\DM-Zeto.unr
IF EXIST Filtered_results\DOM-Cinder.unr del Filtered_results\DOM-Cinder.unr
IF EXIST Filtered_results\DOM-Condemned.unr del Filtered_results\DOM-Condemned.unr
IF EXIST Filtered_results\DOM-Cryptic.unr del Filtered_results\DOM-Cryptic.unr
IF EXIST Filtered_results\DOM-Gearbolt.unr del Filtered_results\DOM-Gearbolt.unr
IF EXIST Filtered_results\DOM-Ghardhen.unr del Filtered_results\DOM-Ghardhen.unr
IF EXIST Filtered_results\DOM-Lament.unr del Filtered_results\DOM-Lament.unr
IF EXIST Filtered_results\DOM-Leadworks.unr del Filtered_results\DOM-Leadworks.unr
IF EXIST Filtered_results\DOM-MetalDream.unr del Filtered_results\DOM-MetalDream.unr
IF EXIST Filtered_results\DOM-Olden.unr del Filtered_results\DOM-Olden.unr
IF EXIST Filtered_results\DOM-Sesmar.unr del Filtered_results\DOM-Sesmar.unr
IF EXIST Filtered_results\DOM-Tutorial.unr del Filtered_results\DOM-Tutorial.unr
IF EXIST Filtered_results\DoorsAnc.uax del Filtered_results\DoorsAnc.uax
IF EXIST Filtered_results\DoorsMod.uax del Filtered_results\DoorsMod.uax
IF EXIST Filtered_results\Editor.u del Filtered_results\Editor.u
IF EXIST Filtered_results\Egypt.utx del Filtered_results\Egypt.utx
IF EXIST Filtered_results\EgyptPan.utx del Filtered_results\EgyptPan.utx
IF EXIST Filtered_results\Ending.umx del Filtered_results\Ending.umx
IF EXIST Filtered_results\engine.u del Filtered_results\engine.u
IF EXIST Filtered_results\Enigma.umx del Filtered_results\Enigma.umx
IF EXIST Filtered_results\Entry.unr del Filtered_results\Entry.unr
IF EXIST Filtered_results\eol.utx del Filtered_results\eol.utx
IF EXIST Filtered_results\EOL_Assault.unr del Filtered_results\EOL_Assault.unr
IF EXIST Filtered_results\EOL_Challenge.unr del Filtered_results\EOL_Challenge.unr
IF EXIST Filtered_results\EOL_CTF.unr del Filtered_results\EOL_CTF.unr
IF EXIST Filtered_results\EOL_Deathmatch.unr del Filtered_results\EOL_Deathmatch.unr
IF EXIST Filtered_results\EOL_Domination.unr del Filtered_results\EOL_Domination.unr
IF EXIST Filtered_results\EOL_Statues.unr del Filtered_results\EOL_Statues.unr
IF EXIST Filtered_results\Extro.uax del Filtered_results\Extro.uax
IF EXIST Filtered_results\Faces.utx del Filtered_results\Faces.utx
IF EXIST Filtered_results\FCommandoSkins.utx del Filtered_results\FCommandoSkins.utx
IF EXIST Filtered_results\Female1Skins.utx del Filtered_results\Female1Skins.utx
IF EXIST Filtered_results\Female1Voice.uax del Filtered_results\Female1Voice.uax
IF EXIST Filtered_results\Female2Skins.utx del Filtered_results\Female2Skins.utx
IF EXIST Filtered_results\Female2Voice.uax del Filtered_results\Female2Voice.uax
IF EXIST Filtered_results\FemaleSounds.uax del Filtered_results\FemaleSounds.uax
IF EXIST Filtered_results\Fire.u del Filtered_results\Fire.u
IF EXIST Filtered_results\firebr.umx del Filtered_results\firebr.umx
IF EXIST Filtered_results\FireEng.utx del Filtered_results\FireEng.utx
IF EXIST Filtered_results\FlareFX.utx del Filtered_results\FlareFX.utx
IF EXIST Filtered_results\Foregone.umx del Filtered_results\Foregone.umx
IF EXIST Filtered_results\FractalFX.utx del Filtered_results\FractalFX.utx
IF EXIST Filtered_results\GenEarth.utx del Filtered_results\GenEarth.utx
IF EXIST Filtered_results\GenFluid.utx del Filtered_results\GenFluid.utx
IF EXIST Filtered_results\GenFX.utx del Filtered_results\GenFX.utx
IF EXIST Filtered_results\GenIn.utx del Filtered_results\GenIn.utx
IF EXIST Filtered_results\GenTerra.utx del Filtered_results\GenTerra.utx
IF EXIST Filtered_results\GenWarp.utx del Filtered_results\GenWarp.utx
IF EXIST Filtered_results\Godown.umx del Filtered_results\Godown.umx
IF EXIST Filtered_results\GothFem.utx del Filtered_results\GothFem.utx
IF EXIST Filtered_results\GothSkins.utx del Filtered_results\GothSkins.utx
IF EXIST Filtered_results\GreatFire.utx del Filtered_results\GreatFire.utx
IF EXIST Filtered_results\GreatFire2.utx del Filtered_results\GreatFire2.utx
IF EXIST Filtered_results\HubEffects.utx del Filtered_results\HubEffects.utx
IF EXIST Filtered_results\Indus1.utx del Filtered_results\Indus1.utx
IF EXIST Filtered_results\Indus2.utx del Filtered_results\Indus2.utx
IF EXIST Filtered_results\Indus3.utx del Filtered_results\Indus3.utx
IF EXIST Filtered_results\Indus4.utx del Filtered_results\Indus4.utx
IF EXIST Filtered_results\Indus5.utx del Filtered_results\Indus5.utx
IF EXIST Filtered_results\Indus6.utx del Filtered_results\Indus6.utx
IF EXIST Filtered_results\Indus7.utx del Filtered_results\Indus7.utx
IF EXIST Filtered_results\IpDrv.u del Filtered_results\IpDrv.u
IF EXIST Filtered_results\IpServer.u del Filtered_results\IpServer.u
IF EXIST Filtered_results\ISVFX.utx del Filtered_results\ISVFX.utx
IF EXIST Filtered_results\JWSky.utx del Filtered_results\JWSky.utx
IF EXIST Filtered_results\LadderFonts.utx del Filtered_results\LadderFonts.utx
IF EXIST Filtered_results\LadderSounds.uax del Filtered_results\LadderSounds.uax
IF EXIST Filtered_results\LadrArrow.utx del Filtered_results\LadrArrow.utx
IF EXIST Filtered_results\LadrStatic.utx del Filtered_results\LadrStatic.utx
IF EXIST Filtered_results\LavaFX.utx del Filtered_results\LavaFX.utx
IF EXIST Filtered_results\Lian-X.utx del Filtered_results\Lian-X.utx
IF EXIST Filtered_results\Liquids.utx del Filtered_results\Liquids.utx
IF EXIST Filtered_results\Lock.umx del Filtered_results\Lock.umx
IF EXIST Filtered_results\Logo.utx del Filtered_results\Logo.utx
IF EXIST Filtered_results\Male1Skins.utx del Filtered_results\Male1Skins.utx
IF EXIST Filtered_results\Male1Voice.uax del Filtered_results\Male1Voice.uax
IF EXIST Filtered_results\Male2Skins.utx del Filtered_results\Male2Skins.utx
IF EXIST Filtered_results\Male2Voice.uax del Filtered_results\Male2Voice.uax
IF EXIST Filtered_results\Male3Skins.utx del Filtered_results\Male3Skins.utx
IF EXIST Filtered_results\MaleSounds.uax del Filtered_results\MaleSounds.uax
IF EXIST Filtered_results\Mech8.umx del Filtered_results\Mech8.umx
IF EXIST Filtered_results\MenuGr.utx del Filtered_results\MenuGr.utx
IF EXIST Filtered_results\Metalmys.utx del Filtered_results\Metalmys.utx
IF EXIST Filtered_results\Mine.utx del Filtered_results\Mine.utx
IF EXIST Filtered_results\Mission.umx del Filtered_results\Mission.umx
IF EXIST Filtered_results\multimesh.u del Filtered_results\multimesh.u
IF EXIST Filtered_results\NaliCast.utx del Filtered_results\NaliCast.utx
IF EXIST Filtered_results\NaliFX.utx del Filtered_results\NaliFX.utx
IF EXIST Filtered_results\Nether.umx del Filtered_results\Nether.umx
IF EXIST Filtered_results\NivenFX.utx del Filtered_results\NivenFX.utx
IF EXIST Filtered_results\noxxsnd.uax del Filtered_results\noxxsnd.uax
IF EXIST Filtered_results\of1.utx del Filtered_results\of1.utx
IF EXIST Filtered_results\Old_FX.utx del Filtered_results\Old_FX.utx
IF EXIST Filtered_results\openingwave.uax del Filtered_results\openingwave.uax
IF EXIST Filtered_results\Organic.umx del Filtered_results\Organic.umx
IF EXIST Filtered_results\Palettes.utx del Filtered_results\Palettes.utx
IF EXIST Filtered_results\Pan1.uax del Filtered_results\Pan1.uax
IF EXIST Filtered_results\Phantom.umx del Filtered_results\Phantom.umx
IF EXIST Filtered_results\PhraelFx.utx del Filtered_results\PhraelFx.utx
IF EXIST Filtered_results\PlayrShp.utx del Filtered_results\PlayrShp.utx
IF EXIST Filtered_results\Queen.utx del Filtered_results\Queen.utx
IF EXIST Filtered_results\rain.uax del Filtered_results\rain.uax
IF EXIST Filtered_results\RainFX.utx del Filtered_results\RainFX.utx
IF EXIST Filtered_results\Razor-ub.umx del Filtered_results\Razor-ub.umx
IF EXIST Filtered_results\relics.u del Filtered_results\relics.u
IF EXIST Filtered_results\Render.utx del Filtered_results\Render.utx
IF EXIST Filtered_results\RotatingU.utx del Filtered_results\RotatingU.utx
IF EXIST Filtered_results\Run.umx del Filtered_results\Run.umx
IF EXIST Filtered_results\SaveMe.umx del Filtered_results\SaveMe.umx
IF EXIST Filtered_results\Savemeg.umx del Filtered_results\Savemeg.umx
IF EXIST Filtered_results\Scripted.utx del Filtered_results\Scripted.utx
IF EXIST Filtered_results\Seeker.umx del Filtered_results\Seeker.umx
IF EXIST Filtered_results\Seeker2.umx del Filtered_results\Seeker2.umx
IF EXIST Filtered_results\SGirlSkins.utx del Filtered_results\SGirlSkins.utx
IF EXIST Filtered_results\ShaneChurch.utx del Filtered_results\ShaneChurch.utx
IF EXIST Filtered_results\ShaneDay.utx del Filtered_results\ShaneDay.utx
IF EXIST Filtered_results\ShaneSky.utx del Filtered_results\ShaneSky.utx
IF EXIST Filtered_results\Skaarj.utx del Filtered_results\Skaarj.utx
IF EXIST Filtered_results\SkTrooperSkins.utx del Filtered_results\SkTrooperSkins.utx
IF EXIST Filtered_results\SkyBox.utx del Filtered_results\SkyBox.utx
IF EXIST Filtered_results\SkyCity.utx del Filtered_results\SkyCity.utx
IF EXIST Filtered_results\Skyward.umx del Filtered_results\Skyward.umx
IF EXIST Filtered_results\Slums.utx del Filtered_results\Slums.utx
IF EXIST Filtered_results\Soldierskins.utx del Filtered_results\Soldierskins.utx
IF EXIST Filtered_results\SpaceFX.utx del Filtered_results\SpaceFX.utx
IF EXIST Filtered_results\Starship.utx del Filtered_results\Starship.utx
IF EXIST Filtered_results\Strider.umx del Filtered_results\Strider.umx
IF EXIST Filtered_results\Suprfist.umx del Filtered_results\Suprfist.umx
IF EXIST Filtered_results\TCrystal.utx del Filtered_results\TCrystal.utx
IF EXIST Filtered_results\Terranius.utx del Filtered_results\Terranius.utx
IF EXIST Filtered_results\TrenchesFX.utx del Filtered_results\TrenchesFX.utx
IF EXIST Filtered_results\TutVoiceAS.uax del Filtered_results\TutVoiceAS.uax
IF EXIST Filtered_results\TutVoiceCTF.uax del Filtered_results\TutVoiceCTF.uax
IF EXIST Filtered_results\TutVoiceDM.uax del Filtered_results\TutVoiceDM.uax
IF EXIST Filtered_results\TutVoiceDOM.uax del Filtered_results\TutVoiceDOM.uax
IF EXIST Filtered_results\UBrowser.u del Filtered_results\UBrowser.u
IF EXIST Filtered_results\UMenu.u del Filtered_results\UMenu.u
IF EXIST Filtered_results\UnrealI.u del Filtered_results\UnrealI.u
IF EXIST Filtered_results\UnrealShare.u del Filtered_results\UnrealShare.u
IF EXIST Filtered_results\UnWorld2.umx del Filtered_results\UnWorld2.umx
IF EXIST Filtered_results\UT.utx del Filtered_results\UT.utx
IF EXIST Filtered_results\UT_ArtFX.utx del Filtered_results\UT_ArtFX.utx
IF EXIST Filtered_results\UTbase1.utx del Filtered_results\UTbase1.utx
IF EXIST Filtered_results\UTBrowser.u del Filtered_results\UTBrowser.u
IF EXIST Filtered_results\UTCredits.unr del Filtered_results\UTCredits.unr
IF EXIST Filtered_results\UTcrypt.utx del Filtered_results\UTcrypt.utx
IF EXIST Filtered_results\UT-Logo-Map.unr del Filtered_results\UT-Logo-Map.unr
IF EXIST Filtered_results\UTMenu.u del Filtered_results\UTMenu.u
IF EXIST Filtered_results\utmenu23.umx del Filtered_results\utmenu23.umx
IF EXIST Filtered_results\UTServerAdmin.u del Filtered_results\UTServerAdmin.u
IF EXIST Filtered_results\UTtech1.utx del Filtered_results\UTtech1.utx
IF EXIST Filtered_results\UTtech2.utx del Filtered_results\UTtech2.utx
IF EXIST Filtered_results\UTtech3.utx del Filtered_results\UTtech3.utx
IF EXIST Filtered_results\Uttitle.umx del Filtered_results\Uttitle.umx
IF EXIST Filtered_results\UWeb.u del Filtered_results\UWeb.u
IF EXIST Filtered_results\UWindow.u del Filtered_results\UWindow.u
IF EXIST Filtered_results\UWindowFonts.utx del Filtered_results\UWindowFonts.utx
IF EXIST Filtered_results\VRikers.uax del Filtered_results\VRikers.uax
IF EXIST Filtered_results\Wheels.umx del Filtered_results\Wheels.umx
IF EXIST Filtered_results\XbpFX.utx del Filtered_results\XbpFX.utx
IF EXIST Filtered_results\XFX.utx del Filtered_results\XFX.utx
IF EXIST Filtered_results\Xtortion.utx del Filtered_results\Xtortion.utx


:Ucheck
IF EXIST Filtered_results\*.u (2>NUL md Filtered_results\System) ELSE GOTO UNRcheck

:UNRcheck
IF EXIST Filtered_results\*.unr (2>NUL md Filtered_results\Maps) ELSE GOTO UTXcheck

:UTXcheck
IF EXIST Filtered_results\*.utx (2>NUL md Filtered_results\Textures) ELSE GOTO UMXcheck

:UMXcheck
IF EXIST Filtered_results\*.umx (2>NUL md Filtered_results\Music) ELSE GOTO UAXcheck

:UAXcheck
IF EXIST Filtered_results\*.uax (2>NUL md Filtered_results\Sounds) ELSE GOTO respectivefolders

:respectivefolders
IF EXIST .\Filtered_results\System Move .\Filtered_results\*.u .\Filtered_results\System >nul 2>&1
IF EXIST .\Filtered_results\Maps Move .\Filtered_results\*.unr .\Filtered_results\Maps >nul 2>&1
IF EXIST .\Filtered_results\Textures Move .\Filtered_results\*.utx .\Filtered_results\Textures >nul 2>&1
IF EXIST .\Filtered_results\Music Move .\Filtered_results\*.umx .\Filtered_results\Music >nul 2>&1
IF EXIST .\Filtered_results\Sounds Move .\Filtered_results\*.uax .\Filtered_results\Sounds >nul 2>&1


ECHO.

:start
ECHO.  Filtered_results has files collected and organized - now compressing.
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
ECHO.
ECHO.
ECHO   This might take a while, please be patient.
ECHO.

:U
IF EXIST .\Filtered_results\System\*.u (
    ECHO   Compressing .U   files [System]...
    
 ) ELSE ( 
    ECHO     .U files not found.   Skipped.
	GOTO :utx
 )

..\system\ucc compress "..\UZ Creation Organizer\Filtered_results\System\*.u" >nul

IF NOT EXIST UZ md UZ >nul
Move .\Filtered_results\System\*.uz UZ >nul
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UTX
IF EXIST .\Filtered_results\Textures\*.utx (
    ECHO   Compressing .UTX files [Textures]...
    
 ) ELSE ( 
    ECHO   .UTX files not found.   Skipped.
	GOTO :umx
 )

..\system\ucc compress "..\UZ Creation Organizer\Filtered_results\Textures\*.utx" >nul

IF NOT EXIST UZ md UZ >nul
Move .\Filtered_results\Textures\*.uz UZ >nul
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UMX
IF EXIST .\Filtered_results\Music\*.umx (
    ECHO   Compressing .UMX files [Music]...
    
 ) ELSE ( 
    ECHO   .UMX files not found.   Skipped.
	GOTO :uax
 )

..\system\ucc compress "..\UZ Creation Organizer\Filtered_results\Music\*.umx" >nul

IF NOT EXIST UZ md UZ >nul
Move .\Filtered_results\Music\*.uz UZ >nul
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UAX
IF EXIST .\Filtered_results\Sounds\*.uax (
    ECHO   Compressing .UAX files [Sounds]...
    
 ) ELSE ( 
    ECHO   .UAX files not found.   Skipped.
	GOTO :unr
 )
..\system\ucc compress "..\UZ Creation Organizer\Filtered_results\Sounds\*.uax" >nul

IF NOT EXIST UZ md UZ >nul
Move .\Filtered_results\Sounds\*.uz UZ >nul
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:UNR
IF EXIST .\Filtered_results\Maps\*.unr (
    ECHO   Compressing .UNR files [Maps]...
    
 ) ELSE ( 
    ECHO   .UNR files not found.   Skipped.
	GOTO :final
 )
 
..\system\ucc compress "..\UZ Creation Organizer\Filtered_results\Maps\*.unr" >nul

IF NOT EXIST UZ md UZ >nul
Move .\Filtered_results\Maps\*.uz UZ >nul
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:final

IF EXIST uz\*.uz (
    ECHO.
	ECHO.
	ECHO   UZ compression finished, see UZ folder. Filtered_results files remain structured in the folder.
    ECHO.
 ) ELSE ( 
	ECHO.
    ECHO   No files with valid extensions were found to be compressed.
ECHO.	
 )
ECHO   Press any key to exit
pause >nul
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::